% Matlab script for plotting a 2D scatterplot exported by Sliver.
% The data is saved in the file "data.csv" which is read in here.
% Refer to the header lines in the data file for more information.
% This script can be customized to add other desired plot features.
%
% Plot properties can also be manually adjusted in Matlab after
% the figure is created through the Edit-->Figure Properties
% menu option.

figureleftmargin = 100;
figurebottommargin = 75;
figureheight = 600;
figurewidth = 1000;

cd(fileparts(which(mfilename)));
data = readtable('data.csv');
filename = data.Properties.VariableNames(4);
filename = strrep(filename,'ddott','.');
filename = strrep(filename,'_','\_');
pointsize = data{1,3};
linewidth = data{1,4};
plotoptions = data{1,5};
xaxisname = char(data{1,1});
xaxisname = strrep(xaxisname,'_','\_');
% The first two values in row 2 are interpreted as strings
% rather than doubles because those values in row 1 (the row
% after the header) are strings, so these need to be converted.
rvalue = str2double(data{2,1});
gvalue = str2double(data{2,2});
bvalue = data{2,3};
lineRGBcolor = [rvalue gvalue bvalue];
filledflag = data{2,4};
numplots = data{2,5};
spaceratio = str2double(data{2,6}) / 100.0;
yaxisname{1} = char(data{1,2});
yaxisname{1} = strrep(yaxisname{1},'_','\_');
for i=2:numplots
	offset = i + 4;
	yaxisname{i} = char(data{1,offset});
	yaxisname{i} = strrep(yaxisname{i},'_','\_');
end

% Remove the first 2 rows of the table, which are
% just passed parameters.
data(1,:) = [];
data(1,:) = [];

% The point color is the same for all plots since they
% share the same x-axis.
pointRGBcolor = data{:,[3 4 5]};

figure('Position',[figureleftmargin figurebottommargin figurewidth figureheight])
% The variables selected first are plotted in the lowest
% subplot, with the other variables plotted above it.
% Plot the subplots from the lowest to the highest.
for i=numplots:-1:1
	stackindex = numplots - i + 1;
	h(i) = subplot(numplots,1,stackindex);
	% Indices of y-variables after the first one follow the
	% three RGB values for the point, so they are offset.
	if i > 1
		ydataindex = i + 4;
	else
		ydataindex = 2;
	end
	if plotoptions == 1
		% A scatterplot of points only.
		if filledflag == 1
			scatter(str2double(data{:,1}),str2double(data{:,ydataindex}), ...
				pointsize,pointRGBcolor,'filled')
		else
			scatter(str2double(data{:,1}),str2double(data{:,ydataindex}), ...
				pointsize,pointRGBcolor)	
		end
	elseif plotoptions == 2
		% A line plot.
		plot(str2double(data{:,1}),str2double(data{:,ydataindex}), ...
			'Color',lineRGBcolor,'LineWidth',linewidth)
	elseif plotoptions == 3
		% A scatterplot and line plot combined.
		% Plot the points on top of the line.
		hold on;
		plot(str2double(data{:,1}),str2double(data{:,ydataindex}), ...
			'Color',lineRGBcolor,'LineWidth',linewidth)
		if filledflag == 1
			scatter(str2double(data{:,1}),str2double(data{:,ydataindex}), ...
				pointsize,pointRGBcolor,'filled')
		else
			scatter(str2double(data{:,1}),str2double(data{:,ydataindex}), ...
				pointsize,pointRGBcolor)	
		end
		hold off;
	end
	ylabel(yaxisname{i});
	% Show major grid lines.
	grid on
	% Show minor grid lines (commented out by default)
	% grid minor
	% Show overall title above the topmost subplot.
	if i == numplots
		title(filename);
	end
end

% Remove excess space between plots.
% bottommargin = y-position of bottom x-axis (from bottom).
% topmargin = y-position of top of top plot (from bottom)
% leaving space for title.
bottommargin = 60;
topmargin = 40;
% V = vertical space minus margins.
V = figureheight - bottommargin - topmargin;
fraction = 1.0 + spaceratio;
n = numplots - 1;
plotspace = V/(n + 1.0/fraction);
plotheight = plotspace / (1.0 + spaceratio);

for i = 1:numplots
    ypos = bottommargin/figureheight + (i-1) * (plotspace/figureheight);
	set (h(i), 'Position', [0.07 ypos 0.9 plotheight/figureheight]);
end

xlabel(xaxisname);
linkaxes(h,'x');
